@@ -12,7 +12,7 @@ import simpleactors as sa
 class ActorSingle(sa.Actor):
 
     @sa.on('echo')
-    def echo(self, message, emitter, a_dictionary):
+    def echo_callback(self, message, emitter, a_dictionary):
         a_dictionary['emitter'] = emitter
 
 
@@ -24,6 +24,15 @@ class ActorDouble(sa.Actor):
         pass
 
 
+class ActorAny(sa.Actor):
+
+    messages = []
+
+    @sa.on(sa.ANY)
+    def any_callback(self, message, emitter, *args, **kwargs):
+        self.messages.append(message)
+
+
 class BaseTest(unittest.TestCase):
 
     '''Base class for all tests of simpleactors.'''
@@ -32,6 +41,33 @@ class BaseTest(unittest.TestCase):
         sa.reset()
 
 
+class TestModuleFunctions(BaseTest):
+
+    '''Tests for the module-level functions.'''
+
+    def test_reset(self):
+        '''reset() clear all registries.'''
+        ActorSingle()
+        self.assertTrue(len(sa.global_actors))
+        self.assertTrue(len(sa.global_actors_by_id))
+        self.assertTrue(len(sa.global_callbacks))
+        sa.reset()
+        self.assertFalse(len(sa.global_actors))
+        self.assertFalse(len(sa.global_actors_by_id))
+        self.assertFalse(len(sa.global_callbacks))
+
+    def test_get_by_id_ok(self):
+        '''get_by_id() return an object with a given ID by a given class.'''
+        actor = sa.Actor(uid='spam')
+        actual = sa.get_by_id(sa.Actor, 'spam')
+        self.assertEqual(actor, actual)
+
+    def test_get_by_id_ko(self):
+        '''get_by_id() return None on "not found" results.'''
+        actual = sa.get_by_id(sa.Actor, 'spam')
+        self.assertEqual(None, actual)
+
+
 class TestActor(BaseTest):
 
     '''Test suite for the Actor class.'''
@@ -44,9 +80,14 @@ class TestActor(BaseTest):
         '''Instantiating an actor add its callback to the global registry.'''
         actor = ActorSingle()
         self.assertTrue(actor.is_plugged)
-        expected = {'echo': set([actor.echo])}
+        expected = {'echo': set([actor.echo_callback])}
         self.assertEqual(expected, sa.global_callbacks)
 
+    def test_double_uid(self):
+        '''Instantiating an actor with existing uid raises.'''
+        sa.Actor(uid='foo')
+        self.assertRaises(ValueError, sa.Actor, uid='foo')
+
     def test_instantiated_no_autoplug(self):
         '''Instantiating an actor with auto_plug set to False prevent plug.'''
         actor = ActorSingle(auto_plug=False)
@@ -76,7 +117,8 @@ class TestActor(BaseTest):
         actor._Actor__plugged = False
         self.assertFalse(actor.is_plugged)
         actor.unplug()
-        self.assertEqual({'echo': set([actor.echo])}, sa.global_callbacks)
+        self.assertEqual({'echo': set([actor.echo_callback])},
+                         sa.global_callbacks)
 
     def test_emit_appends(self):
         '''Emitting an event will append it to the global deque.'''
@@ -136,6 +178,14 @@ class TestDirector(BaseTest):
         director.run()
         self.assertEqual({'emitter': actor}, a_dictionary)
 
+    def test_any(self):
+        '''A callback bound to sa.ANY is triggered by any signal.'''
+        actor = ActorAny()
+        director = sa.Director()
+        actor.emit('foobar')
+        director.run()
+        self.assertEqual([sa.INITIATE, 'foobar'], actor.messages)
+
     def test_run_send_initiate_event(self):
         '''Running the Dirctor emit the INITIATE signal.'''
         director = sa.Director()
@@ -151,10 +201,11 @@ class TestDirector(BaseTest):
         actor = ActorSingle()
         director = sa.Director()
         director.run()
-        expected = {'echo': set([actor.echo]),
+        expected = {'echo': set([actor.echo_callback]),
                     sa.KILL: set([director.kill]),
                     sa.HALT: set([director.halt]),
-                    sa.INITIATE: set()}
+                    sa.INITIATE: set(),
+                    sa.ANY: set()}
         self.assertEqual(expected, sa.global_callbacks)
         self.assertEqual(set([actor, director]), sa.global_actors)
         self.assertEqual(0, len(sa.global_event_queue))
@@ -166,7 +217,7 @@ class TestDirector(BaseTest):
         actor.emit(sa.KILL, target=actor)
         director.run()
         self.assertNotIn(actor, sa.global_actors)
-        self.assertNotIn(actor.echo, sa.global_callbacks['echo'])
+        self.assertNotIn(actor.echo_callback, sa.global_callbacks['echo'])
 
     def test_halt(self):
         '''Halting the directory process FINISH and reset the event queue.'''
